@@ -5,7 +5,7 @@ $self = {
                       'Cairo',
                       'Glib'
                     ],
-          'inc' => '-I/usr/include/cairo -I/usr/include/lzo -I/usr/include/libpng16 -I/usr/include/freetype2 -I/usr/include/harfbuzz -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/sysprof-4 -I/usr/include/pixman-1 -pthread ',
+          'inc' => '-I/usr/include/cairo -I/usr/include/libpng16 -I/usr/include/freetype2 -I/usr/include/harfbuzz -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/sysprof-6 -I/usr/include/pixman-1 -pthread ',
           'libs' => '-lcairo-gobject -lcairo -lgobject-2.0 -lglib-2.0 ',
           'typemaps' => []
         };
